<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

/**
 * Form for editing the block instances.
 *
 * @package   block_bcln_reminder
 * @copyright 2017 BCLN
 * @license   http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

namespace block_bcln_reminder\form;

defined('MOODLE_INTERNAL') || die();

require_once($CFG->libdir.'/formslib.php');

class alert extends \moodleform {
    protected function definition() {
        $mform = $this->_form;
        $type = 'login';
        if (!empty($this->_customdata['type'])) {
            $type = $this->_customdata['type'];
        }
        $course = $this->_customdata['course'];
        $startdate = !empty($course->startdate) ? $course->startdate : time();
        $help_link = "<a href='".get_string('helptext','block_bcln_reminder')."'><b>". get_string('help','block_bcln_reminder')."</b></a>";
        $mform->addElement('static', 'help', $help_link, '');

        $mform->addElement('header', 'addalert', get_string('addalert', 'block_bcln_reminder'));
        $warning = get_string('warning','block_bcln_reminder');
        $mform->addElement('html', '<b>'.$warning.'</b>');
      
        $mform->addElement('static', 'typetext', get_string('type', 'block_bcln_reminder'),
            get_string("type$type", 'block_bcln_reminder'));

        $mform->addElement('selectyesno', 'enabled', get_string('enabled', 'block_bcln_reminder'));
        $mform->setDefault('enabled', 0);

        $mform->addElement('selectyesno', 'progress', get_string('progressreport', 'block_bcln_reminder'));
        $mform->setDefault('progress', 1);
       
        $timewithin = array(
            10  => get_string('numdays', '', 10),
            20  => get_string('numdays', '', 20),
            30  => get_string('numdays', '', 30),
            60  => get_string('numdays', '', 60),
            90  => get_string('numdays', '', 90),
            120 => get_string('numdays', '', 120),
            240 => get_string('numdays', '', 240),
            365 => get_string('numdays', '', 365),
        );
        
        $remindays = array(
            1  => get_string('numdays', '', 1),
            2  => get_string('numdays', '', 2),
            3  => get_string('numdays', '', 3),
            4  => get_string('numdays', '', 4),
            5  => get_string('numdays', '', 5),
            10 => get_string('numdays', '', 10),
            15 => get_string('numdays', '', 15),
            20 => get_string('numdays', '', 20),
        );
        $mform->addElement('select', 'logindays', get_string('logindays', 'block_bcln_reminder'), $timewithin);
        $mform->setDefault('logindays', '30');

        $mform->addElement('select', 'sent1', get_string('remindays', 'block_bcln_reminder'), $remindays);
        $mform->setDefault('remindays', '1');

        if ($type == 'activity') {
            $actlist = array (
                '5' => 'No submissions',
            );
            $mform->addElement('select', 'cmid', 'Activity Type', $actlist);
            
        }

        $mform->addElement('selectyesno', 'msg', get_string('msg', 'block_bcln_reminder'));
        $mform->setDefault('msg', 1);

        $mform->addElement('text', 'subject', get_string('subject', 'block_bcln_reminder'));

        $mform->addElement('textarea', 'template', get_string('alerttemplate', 'block_bcln_reminder'), array('cols' => 40, 'rows' => 5));
        $mform->addHelpButton('template', $type.'alerttemplate', 'block_bcln_reminder');
        $mform->addRule('template', get_string('required'), 'required');

        $mform->addElement('hidden', 'course');
        $mform->setType('course', PARAM_INT);
        $mform->setType('progress', PARAM_INT);

        $mform->addElement('hidden', 'id');
        $mform->setType('id', PARAM_INT);

        $mform->addElement('hidden', 'alerttype');
        $mform->setType('alerttype', PARAM_ALPHA);
        $mform->setDefault('alerttype', $type);

        $mform->setType('msg', PARAM_INT);
        $mform->setType('logindays', PARAM_INT);
        $mform->setType('subject', PARAM_RAW);


        $this->add_action_buttons();
    }

    public function validation($data, $files) {
        $errors = [];
        // Any new alerts setup need to be in the future. So only todays date or higher is accepted.
        $existing = $this->_customdata['alert'];
       /*
        for ($i = 1; $i <=3; $i++) {
            if ($existing->{"alert$i"} != $data["alert$i"] && $data["alert$i"] < usergetmidnight(time())) {
                $errors["alert$i"] = get_string('errorinthepast', 'block_bcln_reminder');
            }
        }

        for ($i = 2; $i <=3; $i++) {
            $field = $data["alert$i"];
            $prev = $i - 1;
            $prevfield = $data["alert$prev"];

            if ($field > 0 && $field < $prevfield) {
                $errors["alert$i"] = get_string('errorearlierthanprevious', 'block_bcln_reminder');
            }
        }
*/
        return $errors;
    }

}
