<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace block_bcln_reminder;

class helper {

    public static function load_alerts_with_track($alertid) {
        global $DB;

        $alertdata = [];
        $alert = alert::instance($alertid);

        $alertdata = [
            [$alert->alert1, 0],
            [$alert->alert2, 0],
            [$alert->alert3, 0],
        ];
        // Get track counts.
        $sql = "SELECT alertnumber, count(userid)
                FROM {block_bcln_reminder_trac}
                WHERE alertid = ?
                GROUP BY alertnumber";
        $tracks = $DB->get_records_sql($sql, [$alert->id]);
        foreach ($tracks as $track) {
            $alertdata[$track->alertnumber - 1][1] = $track->count;
        }

        return $alertdata;
    }

    public static function get_alerts($courseid, $enabledonly = false) {
        global $DB;

        $params = ['course' => $courseid];
        if ($enabledonly) {
            $params['enabled'] = 1;
        }
        $records = $DB->get_records('block_bcln_reminder', $params);
        $alerts = [];
        foreach ($records as $record) {
            $alerts[$record->id] = new alert($record);
        }
        return $alerts;
    }

    public static function get_pending_alert_info() {
        global $DB;

        $time = time();
        $prev = 0;
       // $sql = "SELECT *
       //         FROM {block_bcln_reminder}
       //         WHERE enabled = 1 AND (
       //             (alert1 < ? AND alert1 > 0 AND sent1 = 0) OR
       //             (alert2 < ? AND alert2 > 0 AND sent2 = 0) OR
       //             (alert3 < ? AND alert3 > 0 AND sent3 = 0)
       //         )";
       // $params = [$time, $time, $time];
       
         $sql = "SELECT *
                FROM {block_bcln_reminder}
                WHERE enabled = 1 and lastrun >=".$prev; 
       //             (alert1 < ? AND alert1 > 0 AND sent1 = 0) OR
       //             (alert2 < ? AND alert2 > 0 AND sent2 = 0) OR
       //             (alert3 < ? AND alert3 > 0 AND sent3 = 0)
       //         )";
        $params = [$time, $time, $time];

        $records = $DB->get_records_sql($sql, $params);
        $alerts = [];
        foreach ($records as $record) {
            $alerts[$record->id] = new alert($record);
        }
        return $alerts;
    }

    /**
     * Parse template
     *
     * @param string $template The template to parse.
     * @param object $course Has the id, shortname and fullname of the course.
     * @param object $user A user record.
     * @param object $activity Has the url and name of the activity.
     * @return array The parsed template.
     */
    public static function parse_template($template, $course, $user, $activity = null) {
        $activityurl = isset($activity->url) ? $activity->url : '';
        $activityname = isset($activity->name) ? $activity->name : '';
        $courseurl = new \moodle_url('/course/view.php', array('id' => $course->id));

        $html = str_replace('{clink}', \html_writer::link($courseurl, $course->fullname), $template);
        $html = str_replace('{alink}', \html_writer::link($activityurl, $activityname), $html);
        $html = str_replace('{cfull}', format_string($course->fullname), $html);
        $html = str_replace('{cshort}', format_string($course->shortname), $html);
        $html = str_replace('{userfullname}', $user, $html);
        $html = nl2br($html);

        $text = html_to_text($html);

        return array($text, $html);
    }

    public static function get_cms_without_alert($modinfo, $courseid) {
        global $DB;
        $options = [];
//        foreach ($modinfo->cms as $cmid => $data) {
//            if ($data->completion && !isset($existing[$cmid])) {
 //               $options[$cmid] = $data->name;
  //          }
   //     }
        return $options;
    }

    /**
     * Filters the users in the array who have the role of student.
     *
     * @param array $users Users which may have different roles
     * @param object $alert An instance of the alert itself
     * @param object $context The course context
     * @return array $users The users array with just students only
     */
    public static function filter_by_students($users, $alert, $context) {
        if ($alert->studentsonly and !empty($users)) {
            $userids = get_users_by_capability($context, 'moodle/course:viewhiddencourses', 'u.id');

            $users = array_udiff($users, $userids,
                function ($a, $b) {
                    return $a->id - $b->id;
                }
            );
        }
        return $users;
    }
    
    public static function progress_report($userid, $courseid) {
        global $DB;
        $params = [$userid];
        $sql = "select lastname, firstname from {user} u where u.id = ".$userid;
        $result_student = $DB->get_records_sql($sql,$params);
        foreach($result_student as $student) {
           $nm = $student->firstname.' '.$student->lastname;
        }   
        $base = 'Student: '.$nm; 
        $params = array($courseid,$userid);
        $result_last = $DB->get_records_sql("select * from {user_lastaccess} where courseid=? and userid=? order by timeaccess",$params);
        $ltime = "N/A";
        foreach($result_last as $last) {
           $lt=$last->timeaccess;
           $ltime = date("Y-m-d",$lt);
        }		
        $params21 = array($courseid);
        $result_context = $DB->get_records_sql("select id from {context} where contextlevel <= 50 and instanceid = ? order by contextlevel desc",$params21);
        foreach ($result_context as $ctx) {
           $cid = $ctx->id;
        }  
        $params22 = array($cid);
        $tl = 'N/A';
        $tcnt = 0;
        $result_teacher = $DB->get_records_sql("select lastname,firstname from {role_assignments} r,{user} u where u.id = r.userid and roleid = 3  and contextid = ?",$params22);
        foreach ($result_teacher as $tlist) {
            $tcnt = $tcnt + 1;
            $tn = $tlist->firstname .' '.$tlist->lastname;
            if ($tcnt == 1) {
         	$tl = $tn;
                } else {
                  $tl = $tl.'<br>'.$tn;
                }
            }    
            $result_course = $DB->get_records_sql("select * from {course} where id=?",$params21);
            foreach ($result_course as $crs) {
               $cn = $crs->fullname;
            }
            $base = $base .'<br> Course: '.$cn;
                       	   		                 	         
            $base = $base .'<br> Teacher(s): '.$tl;
            $rdate = date("Y-m-d");
            $base = $base .'<br> Report Date: '.$rdate;
            $base = $base .'<br> Last time in Course: '.$ltime;
                $gtot = 0;
                $result_citem = $DB->get_records_sql("select * from {grade_items} where courseid =? and itemtype = 'course'",$params21);
                foreach ($result_citem as $citem) {
                   $mdlid = $citem->id;
                   $maxgrade = $citem->grademax;
                   $params221 = array($courseid,$userid,$mdlid);
                   $result_final = $DB->get_records_sql("select finalgrade from {grade_grades} gg,{grade_items} gi 
                                                        where gi.id = gg.itemid and courseid=? and userid=? 
                                                        and gi.id=?  and gg.excluded = 0 ",$params221);
                    foreach ($result_final as $cfinal) {
                        $gtot = $cfinal->finalgrade;
                        if ($maxgrade > 100) {
                            $gtot = $gtot / $maxgrade;
                            $gtot = $gtot * 100;
                        } 
                        $gtot = round($gtot,1); 
                   }     
                   $base = $base .'<br> Current Grade in Course: '.$gtot .' %';
	        }
	                        
                $rcomp = $DB->count_records_sql("select COUNT(*) FROM {course_completion_criteria} where course =?",$params21);
                if ($rcomp >= 1) {
                    $params223 = array($courseid,$userid);
                    $result_comp = $DB->count_records_sql("select COUNT(*) FROM {course_completion_crit_compl} where course =?  and userid=?",$params223);
                    $rval = ($result_comp / $rcomp) * 100;
                    $rval = round($rval,1); 
                    $base = $base .'<br> Portion of Course Completed: '.$rval .' %';
	        }    
            $base = $base .'<br><table border="1"><th><b>Activity Name</b></th><th><b>Category </b></th><th><b>Grade</b></th><th><b>Date Submitted</b></th></tr>';
            $params2 = array($courseid);
            $result = $DB->get_records_sql("select * from {course_sections} where course =?",$params2);
            $ln = '';
            //echo 'Course id '.$courseid .' user id '.$userid;
            foreach($result as $seq) {
               $seqarr = $seq->sequence;
               $wordChunks = explode(",", $seqarr);
               for($i = 0; $i < count($wordChunks); $i++){
               	   $sec = $wordChunks[$i];
               	   $params33 = array($sec);
               	   $result_mod = $DB->get_records_sql("select * from {course_modules} where id = ?",$params33);
	           foreach($result_mod as $mlist) {
	                $mtype = $mlist->module;
	                $modid = $mlist->instance;
	                $params44 = array($courseid,$modid);
	                $result5 = $DB->get_records_sql("select * from {grade_items} where courseid = ? and iteminstance=?",$params44);   
	                foreach ($result5 as $item) {
             	            $catid = $item->categoryid;
             	            if (is_null($catid)) {
             	            }	else {
             	                $params2 = array($catid);
                                $result_cat = $DB->get_records_sql("select * from {grade_categories} where  id=? ",$params2); 
                                foreach ($result_cat as $cats) {
             	                    $cn = trim($cats->fullname);
             	                }    
             	                $lc = strlen($cn);
             	                if ($lc > 3) {
             	                    $act = $item->itemname;
                                    $mdlid= $item->id;
                                    $mname = $item->itemmodule;
			            $mgrade = $item->grademax;
			            $mgrade = round($mgrade,2);
                                    $ln=$ln.'<tr><td>'.$act.'</td><td>'.$cn.'</td>';
                                    $params3 = array($courseid,$userid,$mdlid);
                  	            $resultgrade = $DB->get_records_sql("select finalgrade, g.excluded, g.timemodified from {grade_grades} g,{grade_items} gi where gi.id = g.itemid and courseid=? and userid=? and gi.id=? ",$params3);
                                    $cnt = '0';
                                    $grade = 'N/A';
                                    $dmark = 'N/A';
                                    foreach ($resultgrade as $gid) {
                                        $cnt = '1';
                      	                $sgrade = $gid->finalgrade;
                      	                $exclude = $gid->excluded;
                      	                if ($exclude > 0) {
                                       	    $grade = "OMIT";
                                       	    $dmark = "&nbsp;&nbsp;&nbsp;";
                      	                } else {	
                      	                    if (is_null($sgrade)) {
			 	                $dmark = "N/A";
				                $grade = "N/A";
				            } else {
			 	                $sgrade = round($sgrade,2);
					        $grade = $sgrade . "/" . $mgrade;
                                                $dmark = $gid->timemodified;
                                                $dmark = strftime("%Y-%m-%d", $dmark);
                                            }
                                        }         
 				                                         
                                    }
                                    $ln = $ln.'<td>'.$grade.'</td><td>'.$dmark.'</td></tr>';
                                } 
                            }
                        }
                    }
                           
                }
                                                       
            }
            $base = $base.$ln;
            $base = $base.'</table>';
            $messagetext = $base;
            $messagehtml = '<br>'.$base;
            
            return array($messagetext,$messagehtml);
        }

}
