<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace block_bcln_reminder;

class report {

    const PERPAGE = 50;
    protected $offset;
    public $context;
    public $page;
    public $users;

    public function __construct() {
        $this->page = optional_param('page', 0, PARAM_INT);
        $this->offset = $this->page * self::PERPAGE;
        $courseid = required_param('course', PARAM_INT);
        $this->context = \context_course::instance($courseid);
    }

    public function load_login_data() {
        global $DB;
        list($esql, $params) = get_enrolled_sql($this->context, '', 0, true);

        $namefields = get_all_user_name_fields(true, 'u');
        $namesql = $DB->sql_fullname('u.firstname', 'u.lastname');
        $select = "SELECT u.id, u.username, $namesql AS userfullname, $namefields, ul.timeaccess AS accessorstate, '' AS alerts ";
        $count = "SELECT count(1) ";
        $sql = "FROM {user} u
                JOIN ($esql) ue ON ue.id = u.id
                LEFT JOIN {user_lastaccess} ul ON ul.userid = u.id AND ul.courseid = :courseid ";
        $order = "ORDER BY u.username ASC";
        $params['courseid'] = $this->context->instanceid;

        $users = $DB->get_records_sql($select.$sql.$order, $params, $this->offset, self::PERPAGE);
        $count = $DB->count_records_sql($count.$sql, $params);

        $sql = "SELECT t.*
                FROM {block_bcln_reminder_trac} t
                JOIN {block_bcln_reminder} b ON b.course = :courseid AND b.alerttype = 'login' AND b.id = t.alertid
                ORDER BY t.userid ASC, t.alertnumber ASC";
        $params = ['courseid' => $this->context->instanceid];
        $alerts = $DB->get_records_sql($sql, $params);

        $this->users = $users;

        return array($users, $alerts, $count);
    }

    public function load_activity_data(alert $alert) {
        global $CFG, $DB;
        require_once("{$CFG->libdir}/completionlib.php");

        list($esql, $params) = get_enrolled_sql($this->context, '', 0, true);

        $namefields = get_all_user_name_fields(true, 'u');
        $namesql = $DB->sql_fullname('u.firstname', 'u.lastname');
        $select = "SELECT u.id, u.username, $namesql AS userfullname, $namefields, cmc.completionstate AS accessorstate, '' AS alerts ";
        $count = "SELECT count(1) ";
        $sql = "FROM {user} u
                JOIN ($esql) ue ON ue.id = u.id
                LEFT JOIN {course_modules_completion} cmc ON cmc.coursemoduleid = :cmid AND cmc.userid = u.id ";
        $order = "ORDER BY u.username ASC";
        $params['cmid'] = $alert->cmid;
        $users = $DB->get_records_sql($select.$sql.$order, $params, $this->offset, self::PERPAGE);
        $count = $DB->count_records_sql($count.$sql, $params);

        $sql = "SELECT t.*
                FROM {block_bcln_reminder_trac} t
                JOIN {block_bcln_reminder} b ON b.id = :alertid AND t.alertid = b.id
                ORDER BY t.userid ASC, t.alertnumber ASC";
        $params = ['alertid' => $alert->id];
        $alerts = $DB->get_records_sql($sql, $params);

        $this->users = $users;

        return array($users, $alerts, $count);
    }
    public function progress_report($userid, $courseid) {
        $result_student = $DB->get_records_sql("select lastname, firstname from {user} u where u.id = ?",$userid);
        foreach($result_student as $student) {
           $nm = $student->firstname.' '.$student->lastname;
        }   
        $base = 'Student: '.$nm; 
        $params = array($courseid,$userid);
        $result_last = $DB->get_records_sql("select * from {user_lastaccess} where courseid=? and userid=? order by timeaccess",$params);
        $ltime = "N/A";
        foreach($result_last as $last) {
           $lt=$last->timeaccess;
           $ltime = date("Y-m-d",$lt);
        }		
        $params21 = array($courseid);
        $result_context = $DB->get_records_sql("select id from {context} where contextlevel <= 50 and instanceid = ? order by contextlevel desc",$params21);
        foreach ($result_context as $ctx) {
           $cid = $ctx->id;
        }  
        $params22 = array($cid);
        $tl = 'N/A';
        $tcnt = 0;
        $result_teacher = $DB->get_records_sql("select lastname,firstname from {role_assignments} r,{user} u where u.id = r.userid and roleid = 3  and contextid = ?",$params22);
        foreach ($result_teacher as $tlist) {
            $tcnt = $tcnt + 1;
            $tn = $tlist->firstname .' '.$tlist->lastname;
            if ($tcnt == 1) {
         	$tl = $tn;
                } else {
                  $tl = $tl.'<br>'.$tn;
                }
            }    
            $result_course = $DB->get_records_sql("select * from {course} where id=?",$params21);
            foreach ($result_course as $crs) {
               $cn = $crs->fullname;
            }
            $base = $base .'<br> Course: '.$cn;
                       	   		                 	         
            $base = $base .'<br> Teacher(s): '.$tl;
            $rdate = date("Y-m-d");
            $base = $base .'<br> Report Date: '.$rdate;
            $base = $base .'<br> Last time in Course: '.$ltime;
            if ($data->cgrade) {
                $gtot = 0;
                $result_citem = $DB->get_records_sql("select * from {grade_items} where courseid =? and itemtype = 'course'",$params21);
                foreach ($result_citem as $citem) {
                   $mdlid = $citem->id;
                   $maxgrade = $citem->grademax;
                   $params221 = array($courseid,$userid,$mdlid);
                   $result_final = $DB->get_records_sql("select finalgrade from {grade_grades} gg,{grade_items} gi 
                                                        where gi.id = gg.itemid and courseid=? and userid=? 
                                                        and gi.id=?  and gg.excluded = 0 ",$params221);
                    foreach ($result_final as $cfinal) {
                        $gtot = $cfinal->finalgrade;
                        if ($maxgrade > 100) {
                            $gtot = $gtot / $maxgrade;
                            $gtot = $gtot * 100;
                        } 
                        $gtot = round($gtot,1); 
                   }     
                   $base = $base .'<br> Current Grade in Course: '.$gtot .' %';
	        }
	                        
            }
            if ($data->pcomp) {
                $rcomp = $DB->count_records_sql("select COUNT(*) FROM {course_completion_criteria} where course =?",$params21);
                if ($rcomp >= 1) {
                    $params223 = array($courseid,$userid);
                    $result_comp = $DB->count_records_sql("select COUNT(*) FROM {course_completion_crit_compl} where course =?  and userid=?",$params223);
                    $rval = ($result_comp / $rcomp) * 100;
                    $rval = round($rval,1); 
                    $base = $base .'<br> Portion of Course Completed: '.$rval .' %';
	        }    
            }
            $base = $base .'<br><table border="1"><th><b>Activity Name</b></th><th><b>Category </b></th><th><b>Grade</b></th><th><b>Date Submitted</b></th></tr>';
            $params2 = array($courseid);
            $result = $DB->get_records_sql("select * from {course_sections} where course =?",$params2);
            $ln = '';
            //echo 'Course id '.$courseid .' user id '.$userid;
            foreach($result as $seq) {
               $seqarr = $seq->sequence;
               $wordChunks = explode(",", $seqarr);
               for($i = 0; $i < count($wordChunks); $i++){
               	   $sec = $wordChunks[$i];
               	   $params33 = array($sec);
               	   $result_mod = $DB->get_records_sql("select * from {course_modules} where id = ?",$params33);
	           foreach($result_mod as $mlist) {
	                $mtype = $mlist->module;
	                $modid = $mlist->instance;
	                $params44 = array($courseid,$modid);
	                $result5 = $DB->get_records_sql("select * from {grade_items} where courseid = ? and iteminstance=?",$params44);   
	                foreach ($result5 as $item) {
             	            $catid = $item->categoryid;
             	            if (is_null($catid)) {
             	            }	else {
             	                $params2 = array($catid);
                                $result_cat = $DB->get_records_sql("select * from {grade_categories} where  id=? ",$params2); 
                                foreach ($result_cat as $cats) {
             	                    $cn = trim($cats->fullname);
             	                }    
             	                $lc = strlen($cn);
             	                if ($lc > 3) {
             	                    $act = $item->itemname;
                                    $mdlid= $item->id;
                                    $mname = $item->itemmodule;
			            $mgrade = $item->grademax;
			            $mgrade = round($mgrade,2);
                                    $ln=$ln.'<tr><td>'.$act.'</td><td>'.$cn.'</td>';
                                    $params3 = array($courseid,$userid,$mdlid);
                  	            $resultgrade = $DB->get_records_sql("select finalgrade, g.excluded, g.timemodified from {grade_grades} g,{grade_items} gi where gi.id = g.itemid and courseid=? and userid=? and gi.id=? ",$params3);
                                    $cnt = '0';
                                    $grade = 'N/A';
                                    $dmark = 'N/A';
                                    foreach ($resultgrade as $gid) {
                                        $cnt = '1';
                      	                $sgrade = $gid->finalgrade;
                      	                $exclude = $gid->excluded;
                      	                if ($exclude > 0) {
                                       	    $grade = "OMIT";
                                       	    $dmark = "&nbsp;&nbsp;&nbsp;";
                      	                } else {	
                      	                    if (is_null($sgrade)) {
			 	                $dmark = "N/A";
				                $grade = "N/A";
				            } else {
			 	                $sgrade = round($sgrade,2);
					        $grade = $sgrade . "/" . $mgrade;
                                                $dmark = $gid->timemodified;
                                                $dmark = strftime("%Y-%m-%d", $dmark);
                                            }
                                        }         
 				                                         
                                    }
                                    $ln = $ln.'<td>'.$grade.'</td><td>'.$dmark.'</td></tr>';
                                } 
                            }
                        }
                    }
                           
                }
                                                       
            }
            $base = $base.$ln;
            $base = $base.'</table>';
            $messagetext = $messagetext.'  '.$base;
            $messagehtml = $messagehtml.'<br>'.$base;
            return array($messagetext,$messagehtml);
        }
}
