<?php
// This file is part of Moodle - http://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <http://www.gnu.org/licenses/>.

namespace block_bcln_reminder\task;
use block_bcln_reminder\helper;

class sendalerts extends \core\task\scheduled_task {

    /**
     * Get a descriptive name for this task (shown to admins).
     *
     * @return string
     */
    public function get_name() {
        return get_string('sendalertstask', 'block_bcln_reminder');
    }

    public function execute() {
        global $CFG, $DB;
        require_once("{$CFG->libdir}/completionlib.php");
        $pending = helper::get_pending_alert_info();

        // Preload course info.
        $courseids = array_map(function($alert) {
            return $alert->course;
        }, $pending);

        $courses = $DB->get_records_list('course', 'id', $courseids, '', 'id, shortname, fullname, visible');
        $subject = get_string('subject', 'block_bcln_reminder');

        $ccusers = [];
        foreach ($courses as $course) {
            $ccusers[$course->id] = get_enrolled_users(\context_course::instance($course->id), 'moodle/course:update');
        }
        foreach ($pending as $alert) {
            $cc = isset($ccusers[$alert->course]) ? $ccusers[$alert->course] : [];
            $aid = $alert->id;
            // see when the last alert was run
            $tme = $alert->lastrun;
            $valid = '0';
            if (empty($tme)) {
                $valid = '1';
            }
            $tme = time() - $tme;
            
            if ($tme > '86400') {
                $valid = '1';
            }
    //        $valid = '1';
            
            if ($valid == '1' ) {
               if ($alert->alerttype == 'login') {
  //               echo 'in send login alert for '.$alert->course;
                   $this->process_login_alert($alert, $courses, $alert->subject, $cc);
                   $DB->execute("UPDATE {block_bcln_reminder} SET lastrun=? WHERE id=?", array(time(), $aid));
                } else {
                   $sql2 = "SELECT id from {assign} where course = :courseid";
                   $params2['courseid'] = $alert->course;
                   $assignlist = $DB->get_records_sql($sql2, $params2);
                   $ct = '0';
                   foreach ($assignlist as $assign) {
                      $ct = $ct +1;
                    }
                    if ($ct > '0') {
                       $this->process_activity_alert($alert, $courses, $alert->subject, $cc);
                    }    
                    $DB->execute("UPDATE {block_bcln_reminder} SET lastrun=? WHERE id=?", array(time(), $aid));
                }
            }
        }
        
    }

    protected function process_activity_alert($alert, $courses, $subject, $ccusers) {
        global $DB, $SITE;
        mtrace("Processing bcln_reminder for No Submissions");

        $dayslast = $alert->logindays;
        $dayslast = $dayslast * 24 * 60 * 60;
        $dayslast = time() - $dayslast;
        $daysend = $alert->sent1;
        $daysend = $daysend * 24 * 60 * 60;
        $daysend = $dayslast + $daysend;

        $params['courseid'] = $alert->course;
        $role = $DB->get_record('role', array('shortname' => 'editingteacher'));
        $context = \context_course::instance($alert->course);
        
        $teachers = get_role_users($role->id, $context);
        $teacherid = '0';
        foreach ($teachers as $teacher) {
           $teacherid = $teacher->id;
        }
        $from = $DB->get_record('user',array('id' =>$teacherid));
        $cid = $alert->course;
        $sql = " SELECT u.id,  u.lastname, u.firstname, u.email
                 FROM {course} c
                 JOIN {context} ct ON c.id = ct.instanceid
                 JOIN {role_assignments} ra ON ra.contextid = ct.id
                 JOIN {user} u ON u.id = ra.userid
                 JOIN {role} r ON r.id = ra.roleid
                 JOIN {enrol} e ON e.courseid = c.id
                 JOIN {user_enrolments} us ON us.enrolid = e.id   
                 and us.userid = u.id  
                 WHERE c.id = '".$cid."' 
                 AND u.deleted = 0 and u.suspended = 0 and us.status = 0
                 AND r.id = 5";

//echo $sql;

        $l2 = $DB->get_records_sql($sql, $params);
        foreach ($l2 as $lrn) {
            // check for all assignments in the course
           // echo ' looking for '.$lrn->id;
            $params2['courseid'] = $alert->course;
            $sql2 = "SELECT id from {assign} where course = :courseid";
            $assignlist = $DB->get_records_sql($sql2, $params2);
            $ct =0;
            foreach ($assignlist as $assign) {
               $assignid = $assign->id;
               $count = $DB->count_records_select('assign_submission', 'assignment='.$assignid .' and userid='.$lrn->id .' and timemodified >='.$dayslast .' and timemodified >='.$daysend .'');
               $ct = $ct + $count;
            }
            if ($ct == '0') {
                $fn = $lrn->firstname .' '.$lrn->lastname;
                list($text, $html) = helper::parse_template($alert->template, $courses[$alert->course], $fn);
              
                if ($alert->progress == '1') {
                    $uid = $learner->id;
                    $ret = helper::progress_report($uid,$alert->course);
                    $text1 = $ret[0];
                    $text = $text .'<br>'.$text1;
                    $text1html = $ret[1];
                }
                $subj2 = $alert->subject;
              //  echo 'help 22  '.$html;
                $tempuser = $DB->get_record('user', array('id' => $lrn->id), '*', MUST_EXIST);
            
                //print_r($tempuser);
                email_to_user($tempuser,$from,$subject,$text);
    
              
                if ($alert->msg == '1') {       
                    $message = new \core\message\message();
                    $message->component = 'moodle';
                    $message->name = 'instantmessage';
                    $message->userfrom = $teacherid;
                    $message->userto = $lrn->id;
                    $message->subject = $subj2;
                    $message->fullmessage = $html;
                    $message->fullmessageformat = FORMAT_MARKDOWN;
                    $message->fullmessagehtml = $html;
                    $message->smallmessage = $html;
                    $message->notification = '0';
                    $message->replyto = $from->email;
                    $message->courseid = SITEID;
        
                    $messageid = message_send($message);
                   // echo 'learner '.$lrn->id;
                }
            }
              
        }
        return ( True );
    
    }

  
    protected function process_login_alert($alert, $courses, $subject, $ccusers) {
        global $DB, $SITE;
        mtrace("Processing bcln_reminder_login_alert for courseid: {$alert->course}");
        // Get users who haven't viewed the course.
        $context = \context_course::instance($alert->course);
        $role = $DB->get_record('role', array('shortname' => 'editingteacher'));

        $teachers = get_role_users($role->id, $context);
        $teacherid = '0';
        foreach ($teachers as $teacher) {
           $teacherid = $teacher->id;
        }
        $from = $DB->get_record('user',array('id' =>$teacherid));
                
        list($esql, $params) = get_enrolled_sql($context, '', 0, true);
        $dayslast = $alert->logindays;
        $dayslast = $dayslast * 24 * 60 * 60;
        $dayslast = time() - $dayslast;
        $params['courseid'] = $alert->course;
        $params['dayslast'] = $dayslast;
        
        $daysend = $alert->sent1;
        $daysend = $daysend * 24 * 60 * 60;
        $daysend = $dayslast - $daysend;
        $params['daysend'] = $daysend;
        
 
        $sql = " SELECT c.id courseid, u.id, u.lastname, u.firstname, u.email
                 FROM {course} c
                 JOIN {context} ct ON c.id = ct.instanceid
                 JOIN {role_assignments} ra ON ra.contextid = ct.id
                 JOIN {user} u ON u.id = ra.userid
                 JOIN {role} r ON r.id = ra.roleid
                 JOIN {user_lastaccess} la ON la.userid = u.id
                 JOIN {enrol} e ON e.courseid = c.id
                 JOIN {user_enrolments} us ON us.enrolid = e.id   
                 and us.userid = u.id  
                 WHERE c.id = :courseid
                 AND la.courseid = c.id
                 AND u.deleted = 0 and u.suspended = 0
                 AND la.timeaccess >= :daysend
                 AND la.timeaccess <= :dayslast
                 AND us.status = 0
                 AND r.id = 5";
        
        $learners = $DB->get_records_sql($sql, $params);
        
        // Assuming they can view the course at all, email them an alert.
        foreach ($learners as $learner) {
            $sqlvalid = " SELECT mu.status
                          FROM {user_enrolments} mu,{enrol} en
                          WHERE en.id = mu.enrolid
                          AND en.courseid = ? AND userid = ?";
            $params2['courseid'] = $alert->course;
            $params2['dayslast'] = $learner->userid;
            $validlearners = $DB->get_records_sql($sqlvalid, $params2);
            $valid = '0';
            foreach ($validlearners as $validlearn) {
                $valid = $validlearn;
            }
            if ($valid == '0') {
                $text1 ='';
                $text1html = '';
                if ($alert->progress == '1') {
                   $uid = $learner->userid;
                   $ret = helper::progress_report($uid,$alert->course);
                   $text1 = $ret[0];
                   $text1html = $ret[1];
                }
               $ss = $subject;
               $fn = $learner->firstname .' '.$learner->lastname;
               list($text, $html) = helper::parse_template($alert->template, $courses[$alert->course], $fn);
               $tempuser = $DB->get_record('user', array('id' => $learner->id), '*', MUST_EXIST);
               if ($alert->msg == '1') {             
                   $message = new \core\message\message();
                   $message->component = 'moodle';
                   $message->name = 'instantmessage';
                   $message->userfrom = $teacherid;
                   $message->userto = $learner->id;
                   $message->subject = $subject;
                   $message->fullmessage = $html;
                   $message->fullmessageformat = FORMAT_MARKDOWN;
                   $message->fullmessagehtml = $html;
                   $message->smallmessage = $html;
                   $message->notification = '0';
                   $message->replyto = $from->email;
                   $message->courseid = SITEID;
                   $messageid = message_send($message);
                }
            }
      //      $alert->track($learner->userid);
       }
     //   $alert->set_sent_and_save();
      return ( True );
    }

}
